##  Requirements for SBOMs
  * Libraries must have a valid purl (package URL), as specified in the [Package URL Specification![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fgithub.com%2Fpackage-url%2Fpurl-spec%2Fblob%2Fmaster%2FPURL-SPECIFICATION.rst "https://github.com/package-url/purl-spec/blob/master/PURL-SPECIFICATION.rst").
  * For the CycloneDX format, only SBOM components of the type [library![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fcyclonedx.org%2Fdocs%2F1.6%2Fjson%2F%23components_items_type "https://cyclonedx.org/docs/1.6/json/#components_items_type") can be processed.


**Note**
SAP LeanIX does not offer capabilities for automatic SBOM generation. You can generate SBOMs using a method of your choice and import them to SAP LeanIX using the [Self-Built Software Discovery API![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Feu.leanix.net%2Fservices%2Ftechnology-discovery%2Fv1%2Fopenapi%2Fswagger-ui%2Findex.html?locale=en-US&state=PRODUCTION&version=CLOUD "https://eu.leanix.net/services/technology-discovery/v1/openapi/swagger-ui/index.html"). In this context, SAP LeanIX is a downstream consumer, not producer.
SAP LeanIX does not check the quality or sanitize your SBOMs. To evaluate their quality, you can use any third-party tools such as [sbomqs![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fgithub.com%2Finterlynk-io%2Fsbomqs "https://github.com/interlynk-io/sbomqs").
